#!/usr/bin/python
#
# Lifelines report: index_mml.ll
# Author: Jim Eggert
#
# Python/GEDitCOM II conversion: index-mm.py
# Author: John A. Nairn
#
# An index of all individual with birth, death and married dates
# Males show only first marriage date
# Females lists by maiden name (first marriage date only) and
#    also by married names (using spouse's surnamne)
# Name sorted by last names (if index is sorted), but extra
#    entries for families not sorted but next to maiden name

# Load Lifelines Module
from lifelines import *
from operator import ge,eq

# Preamble
gdoc = ll_init("index_mm.ll program")

# LifeLines index_mm.ll program translation

names = list()
keys = list()
indices = list()

# change this value as needed
# total width is 8+nameWidth+3*datewidth
# Emulation added date width and trim dates to fit if needed
namewidth = 44
datewidth = 18

bcol = 8+namewidth
dcol = bcol+datewidth
mcol = dcol+datewidth
cols(". .",8,"LAST, First Middle [MAIDEN]",bcol,"Birthdate",dcol)
cols("Deathdate",1+mcol-dcol,"Marriage")
nl()

marriednum = 0
message("Writing names...")
numindi = count("INDI")
nextrep = 0
for (num0,person) in forindi() :
    num = num0+1
    if ge(num,nextrep) :
        # emulation changed to percent done in message area
        message(None,float(num)/float(numindi))
        nextrep = nextrep+int(numindi/100)
    b = birth(person)
    if b :
        bdate = date(b)
    else :
        bdate = date(baptism(person))
    bdate = trim(bdate,datewidth)
    d = death(person)
    if d :
        ddate = date(d)
    else :
        ddate = date(burial(person))
    ddate = trim(ddate,datewidth)
    kp = key(person)
    pn = fullname(person,1,0,namewidth)
    cols(kp,8,pn,bcol,bdate,dcol,ddate,mcol)
    (fam,spouse,fnum,iter) = families(person)
    if fam :
        cols(trim(date(marriage(fam)),datewidth))
    nl()
    if female(person) :
        maidenname = save(concat(", ",fullname(person,1,1,100)))
        (spouse,fam,fnum,iter) = spouses(person)
        while spouse :
            spousesurname = surname(spouse)
            if spousesurname :
                kp = key(person)
                mn = trim(concat(upper(spousesurname),maidenname),namewidth)
                mdate = trim(date(marriage(fam)),datewidth)
                cols(kp,8,mn,bcol,bdate,dcol,ddate,mcol,mdate)
                nl()
                marriednum = marriednum+1
            (spouse,fam,fnum) = spouses(iter)
result = "Wrote "+str(num)+" database names and "+str(marriednum)+" married names."
message(result,1)
    
# Script output
finish()
print("Done")


