#!/usr/bin/python
#
# Lifelines report: 4gen1.ll
# Author: Wetmore, Thomas Trask
#
# Python/GEDitCOM II conversion: 4gen1.py
# Author: John A. Nairn

# Load GEDitCOM II Module
from GEDitCOMII import *

# Subroutines

def pedout(indi,gen,cell) :
    if indi :
        block(indi,gen,cell)
        if gen<= 3 :
           # 1->4, 2->2, 3->1
           shift = 2 ** (3-gen)
           gen += 1
           fath = GetFather(indi)
           moth = GetMother(indi)
           pedout(fath,gen,cell-shift)
           pedout(moth,gen,cell+shift)

def block(indi,gen,cell) :
    global cells
    blck = indi.name()
    bd = indi.birthDate()
    blck += "\n  b. "+bd
    bp = indi.birthPlace()
    blck += "\n  bp. "+bp
    cells.pop(cell-1)
    cells.insert(cell-1,blck)

# Preamble
scriptName = "Four Generation Text Chart"
gedit = CheckVersionAndDocument(scriptName)
gdoc = FrontDocument()
rpt = ScriptOutput(scriptName,"monospace")
cols = 80
rpt.setMonoBlock(61,cols,4,2)

# individual
indi = GetIndividual()
if not(indi) :
    Alert("The have to select an individual before running this script",\
    "Select an individual and try again")
    quit()
    
# empty cells
cells = []
for i in range(15) :
    cells.append("____________________\n  b.\n  bp.")

# loop over individuals
pedout(indi,1,8)

# title
htext = "Four Generation Chart for "+indi.name()
rpt.setHeaderText(htext.center(80))
ftext = "Printed "+gdoc.dateToday()
rpt.setFooterText(ftext.center(80))

# print lines to report
rpt.blockheader()
cell = 0
for i in range(15) :
    cell = i+1
    if cell%8 == 0 :
       gen = 1
    elif cell%4 ==0 :
       gen = 2
    elif cell%2 == 0 :
       gen = 3
    else :
       gen = 4
    skip = 12*(gen-1)-1
    if skip>0 :
        prfx = "| "
    else :
        skip = 1
        prfx = ""
    ilines = cells[i].split("\n")
    for j in range(3) :
        if skip+2+len(ilines[j])>cols :
            fits = cols-skip-1
            ilines[j] = ilines[j][0:fits]
        rpt.cols(["",skip,prfx+ilines[j]])
        rpt.newline()
    if i!=14 :
        rpt.newline()
rpt.blockfeed(False)

# final output
rpt.write()

