#!/usr/bin/python
#
# Lifelines report 6gen1.ll
# Author: Tom Wetmore, Cliff Manis
#
# Python/GEDitCOM II conversion: 6gen1_gc_tt.py
# Author: John A. Nairn

# Load GEDitCOM II Module
from GEDitCOMII import *

# Subroutines

def pedout(indi,gen,cell) :
    if indi :
        block(indi,gen,cell)
        if gen<=5 :
           # 1->16, 2->8, 3->4, 4->2, 5->1
           shift = 2 ** (5-gen)
           gen += 1
           fath = GetFather(indi)
           moth = GetMother(indi)
           pedout(fath,gen,cell-shift)
           pedout(moth,gen,cell+shift)

def block(indi,gen,cell) :
    global cells
    cells.pop(cell-1)
    cells.insert(cell-1,indi.alternateName())

# Preamble
scriptName = "Four Generation Text Chart"
gedit = CheckVersionAndDocument(scriptName)
gdoc = FrontDocument()
rpt = ScriptOutput(scriptName,"monospace")
cols = 80
rpt.setMonoBlock(63,cols,2,2)

# individual
indi = GetIndividual()
if not(indi) :
    Alert("The have to select an individual before running this script",\
    "Select an individual and try again")
    quit()
    
# empty cells
cells = []
for i in range(63) :
    cells.append("____________________")

# loop over individuals
pedout(indi,1,32)

# title
htext = "Six Generation Chart for "+ indi.alternateName()
rpt.setHeaderText(htext.center(80))
ftext = "Printed "+gdoc.dateToday()
rpt.setFooterText(ftext.center(80))

indent = 10
blnk = "          "
blnkm1 = "         "
vert = "|"

# print lines to report
rpt.blockheader()
for i in range(63) :
    cell = i+1
    rank = cell
    if rank>32 :
        rank = 64-cell
    prfx = ""
    if cell%32 == 0 :
       gen = 1
    elif cell%16 == 0 :
       gen = 2
    elif cell%8 == 0 :
       gen = 3
       if rank==24 :
           prfx = blnk+vert
    elif cell%4 ==0 :
       gen = 4
       if rank==12 :
           prfx = blnk+blnk+vert
       elif rank==20 :
           prfx = blnk+vert+blnkm1+vert
       elif rank==28:
           prfx = blnk+vert
    elif cell%2 == 0 :
       gen = 5
       if rank==6:
           prfx = blnk+blnk+blnk+vert
       elif rank==10:
           prfx = blnk+blnk+vert+blnkm1+vert
       elif rank==14:
           prfx = blnk+blnk+vert
       elif rank==18:
           prfx = blnk+vert+blnkm1+vert
       elif rank==22:
           prfx = blnk+vert+blnkm1+vert+blnkm1+vert
       elif rank==26:
           prfx = blnk+vert+blnkm1+blnk+vert
       elif rank==30:
           prfx = blnk+vert
    else :
       gen = 6
       if rank==3 or rank==5 or rank==11 or rank==13 :
           prfx = blnk+blnk+blnk+blnk+vert
       elif rank==19 or rank==21 or rank==27 or rank==29 :
           prfx = blnk+blnk+blnk+blnk+vert
    skip = indent*(gen-1)+1
    if skip+len(cells[i])>cols :
        fits = cols-skip-1
        cells[j] = cells[i][0:fits]
    rpt.cols([prfx,skip,cells[i]])
    rpt.newline()
rpt.blockfeed(False)

# final output
rpt.write()

